@@ -7,28 +7,35 @@
 #'   standardized regression slopes,
 #'   standard errors,
 #'   test statistics,
+#'   degrees of freedom,
 #'   p-values,
 #'   and
 #'   confidence intervals.
 #'
 #' @param object Object of class `betasandwich`.
 #' @param alpha Numeric vector.
-#'   Significance level.
+#'   Significance level \eqn{\alpha}.
 #'
 #' @family Beta Sandwich Functions
 #' @keywords betaSandwich ci internal
 #' @noRd
 .BetaCI <- function(object,
-                    alpha = c(0.05, 0.01, 0.001)) {
+                    alpha = NULL) {
   stopifnot(
-    methods::is(
+    inherits(
       object,
       "betasandwich"
     )
   )
+  if (is.null(alpha)) {
+    alpha <- object$args$alpha
+  }
+  stopifnot(
+    all(alpha > 0 & alpha < 1)
+  )
   return(
     .CIWald(
-      object$est,
+      est = object$est,
       se = sqrt(diag(object$vcov)),
       theta = 0,
       alpha = alpha,
