@@ -9,31 +9,35 @@
 #'   (R-squared and adjusted R-squared),
 #'   standard errors,
 #'   test statistics,
+#'   degrees of freedom,
 #'   p-values,
 #'   and
 #'   confidence intervals.
 #'
 #' @param object Object of class `rsqbetasandwich`.
 #' @param alpha Numeric vector.
-#'   Significance level.
+#'   Significance level \eqn{\alpha}.
 #'
 #' @family Beta Sandwich Functions
 #' @keywords betaSandwich ci rsq internal
 #' @noRd
 .RSqCI <- function(object,
-                   alpha = c(0.05, 0.01, 0.001)) {
+                   alpha = NULL) {
   stopifnot(
-    methods::is(
+    inherits(
       object,
       "rsqbetasandwich"
     )
   )
+  if (is.null(alpha)) {
+    alpha <- object$args$alpha
+  }
+  stopifnot(
+    all(alpha > 0 & alpha < 1)
+  )
   return(
     .CIWald(
-      c(
-        rsq = object$fit$lm_process$summary_lm$r.squared,
-        adj = object$fit$lm_process$summary_lm$adj.r.squared
-      ),
+      est = object$fit$lm_process$rsq,
       se = sqrt(diag(.RSqCov(object))),
       theta = 0,
       alpha = alpha,
